@@ -1,4 +1,3 @@
-/* $Xorg: do_tests.c,v 1.3 2000/08/17 19:54:10 cpqbld Exp $ */
 /*****************************************************************************
 Copyright 1988, 1989 by Digital Equipment Corporation, Maynard, Massachusetts.
 
@@ -21,7 +20,6 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ******************************************************************************/
-/* $XFree86: xc/programs/x11perf/do_tests.c,v 1.9 2002/05/13 05:27:37 keithp Exp $ */
 
 #include "x11perf.h"
 
@@ -790,7 +788,7 @@ Test test[] = {
 		InitTrapezoids, DoTrapezoids, NullProc, EndTrapezoids,
 		V1_4FEATURE, ROP, 0,
 		{2, 300, "escherknot", NULL, FillTiled}},
-#ifdef XRENDER
+#if defined(XRENDER) && defined(XFT)
   {"-aatrap1", "Fill 1x1 aa trap", NULL,
 		InitFixedTraps, DoFixedTraps, NullProc, EndFixedTraps,
 		V1_5FEATURE, NONROP, 0,
@@ -1212,6 +1210,30 @@ Test test[] = {
 		InitShmPutImage, DoShmPutImage, MidCopyPix, EndShmPutImage,
 		V1_4FEATURE, ROP, 0,
 		{4, 500, "XY"}},
+  {"-shmget10", "ShmGetImage 10x10 square", NULL,
+		InitShmGetImage, DoShmGetImage, NullProc, EndShmGetImage,
+		V1_2FEATURE, ROP, 0,
+		{4, 10}},
+  {"-shmget100", "ShmGetImage 100x100 square", NULL,
+		InitShmGetImage, DoShmGetImage, NullProc, EndShmGetImage,
+		V1_2FEATURE, ROP, 0,
+		{4, 100}},
+  {"-shmget500", "ShmGetImage 500x500 square", NULL,
+		InitShmGetImage, DoShmGetImage, NullProc, EndShmGetImage,
+		V1_2FEATURE, ROP, 0,
+		{4, 500}},
+  {"-shmgetxy10", "ShmGetImage XY 10x10 square", NULL,
+		InitShmGetImage, DoShmGetImage, NullProc, EndShmGetImage,
+		V1_4FEATURE, ROP, 0,
+		{4, 10, "XY"}},
+  {"-shmgetxy100", "ShmGetImage XY 100x100 square", NULL,
+		InitShmGetImage, DoShmGetImage, NullProc, EndShmGetImage,
+		V1_4FEATURE, ROP, 0,
+		{4, 100, "XY"}},
+  {"-shmgetxy500", "ShmGetImage XY 500x500 square", NULL,
+		InitShmGetImage, DoShmGetImage, NullProc, EndShmGetImage,
+		V1_4FEATURE, ROP, 0,
+		{4, 500, "XY"}},
 #endif
   {"-getimage10", "GetImage 10x10 square", NULL,
 		InitGetImage, DoGetImage, NullProc, EndGetImage,
@@ -1237,6 +1259,30 @@ Test test[] = {
 		InitGetImage, DoGetImage, NullProc, EndGetImage,
 		V1_4FEATURE, PLANEMASK, 0,
 		{4, 500, "XY"}},
+  {"-compwinwin10", "Composite 10x10 from window to window", NULL,
+		InitCompositeWin, DoCompositeWinWin, MidScroll, EndCompositeWin,
+		VERSION1_6, COMP, 0,
+		{4, 10}},
+  {"-compwinwin100", "Composite 100x100 from window to window", NULL,
+		InitCompositeWin, DoCompositeWinWin, MidScroll, EndCompositeWin,
+		VERSION1_6, COMP, 0,
+		{4, 100}},
+  {"-compwinwin500", "Composite 500x500 from window to window", NULL,
+		InitCompositeWin, DoCompositeWinWin, MidScroll, EndCompositeWin,
+		VERSION1_6, COMP, 0,
+		{4, 500}},
+  {"-comppixwin10", "Composite 10x10 from pixmap to window", NULL,
+		InitCompositePix, DoCompositePixWin, MidScroll, EndCompositeWin,
+		VERSION1_6, COMP, 0,
+		{4, 10}},
+  {"-comppixwin100", "Composite 100x100 from pixmap to window", NULL,
+		InitCompositePix, DoCompositePixWin, MidScroll, EndCompositeWin,
+		VERSION1_6, COMP, 0,
+		{4, 100}},
+  {"-comppixwin500", "Composite 500x500 from pixmap to window", NULL,
+		InitCompositePix, DoCompositePixWin, MidScroll, EndCompositeWin,
+		VERSION1_6, COMP, 0,
+		{4, 500}},
   {"-noop",     "X protocol NoOperation", NULL,
 		NullInitProc, DoNoOp, NullProc, NullProc,
 		V1_2FEATURE, PLANEMASK, 0,
